@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::GETTY::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.001';
+  $Dist::Zilla::PluginBundle::Author::GETTY::VERSION = '0.002';
 }
 # ABSTRACT: BeLike::GETTY when you build your dists
 
@@ -139,7 +139,7 @@ Dist::Zilla::PluginBundle::Author::GETTY - BeLike::GETTY when you build your dis
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
@@ -170,6 +170,13 @@ This is the plugin bundle that GETTY uses.  It is equivalent to:
   tag_format = %v
   push_to = origin
 
+  [ChangelogFromGit]
+  max_age = 99999
+  tag_regexp = ^v(.+)$
+  file_name = Changes
+  wrap_column = 74
+  debug = 0
+
 If the C<task> argument is given to the bundle, PodWeaver is replaced with
 TaskWeaver and Git::NextVersion is replaced with AutoVersion.  If the
 C<manual_version> argument is given, AutoVersion is omitted. 
